#
# spec file for package python3-scikit-image
#
# Copyright (c) 2016 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           python3-scikit-image
Version:        0.12.3
Release:        1.4
Summary:        Collection of algorithms for image processing in Python
License:        BSD-3-Clause
Group:          Productivity/Scientific/Other
Url:            http://scikit-image.org/
Source0:        https://files.pythonhosted.org/packages/source/s/scikit-image/scikit-image-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  freeimage-devel
BuildRequires:  python3-Cython >= 0.17
BuildRequires:  python3-devel
BuildRequires:  python3-matplotlib >= 1.0
BuildRequires:  python3-nose
BuildRequires:  python3-numpy-devel >= 1.6
BuildRequires:  python3-qt4-devel
BuildRequires:  python3-scipy >= 0.10
BuildRequires:  python3-setuptools
BuildRequires:  python3-networkx
BuildRequires:  python3-Pillow
Requires:       python3 >= 2.5
Requires:       python3-Cython >= 0.17
Requires:       python3-matplotlib >= 1.0
Requires:       python3-numpy >= 1.6
Requires:       python3-scipy >= 0.10
Requires:       python3-networkx
Requires:       python3-Pillow
Recommends:     libfreeimage3
Recommends:     python3-qt4
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%{py_requires}

%description
%{name} is a collection of algorithms for image processing in Python.
It is available free of charge and free of restriction.

%prep
%setup -q -n scikit-image-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
%fdupes -s %{buildroot}

mkdir -p %{buildroot}%{_sysconfdir}/alternatives
mv %{buildroot}%{_bindir}/skivi %{buildroot}%{_bindir}/skivi-%{py3_ver}
ln -s -f %{_sysconfdir}/alternatives/skivi %{buildroot}%{_bindir}/skivi
# create a dummy target for /etc/alternatives/skivi
touch %{buildroot}%{_sysconfdir}/alternatives/skivi

%post
update-alternatives \
   --install %{_bindir}/skivi skivi %{_bindir}/skivi-%{py3_ver} 30

%preun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove skivi %{_bindir}/skivi-%{py3_ver}
fi


%files
%defattr(-,root,root)
%doc CONTRIBUTING.txt CONTRIBUTORS.txt LICENSE.txt TASKS.txt TODO.txt
%{_bindir}/skivi
%{_bindir}/skivi-%{py3_ver}
%ghost %{_sysconfdir}/alternatives/skivi
%{python3_sitearch}/skimage/
%{python3_sitearch}/scikit_image-%{version}-py*.egg-info

%changelog
* Mon Jun 13 2016 toddrme2178@gmail.com
- Remove unneeded test dependencies.
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Fri Mar 11 2016 toddrme2178@gmail.com
- Update to version 0.12.3
  * Add inpaint to module init
  * Changed docsting sections order
* Tue Mar  8 2016 arun@gmx.de
- update to version 0.12.2:
  (taken from git, including 0.12.1)
  * Add .in files to source distribution
  * Warn if user tries to build with older Cython version
  * Remove left-over mentions in test docstrings of lena
  * Fix 2.6 compatibility
  * Remove lena image from test suite.
  * Bring release notes and API changes in sync
* Mon Mar  7 2016 arun@gmx.de
- update to version 0.12.0:
  * Highlights include:
    + 3D skeletonization (#1923)
    + Parallelization framework using
    "dask":"skimage.util.apply_parallel" (#1493)
    + Laplacian operator "filters.laplace" (#1763)
    + Synthetic 2-D and 3-D binary data with rounded blobs (#1485)
    + Plugin for "imageio" library (#1575)
    + Inpainting algorithm (#1804)
    + New handling of background pixels for "measure.label": 0-valued
    pixels are considered as background by default, and the label of
    background pixels is 0.
    + Partial support of 3-D images for "skimage.measure.regionprops"
    (#1505)
    + Multi-block local binary patterns (MB-LBP) for texture
    classification (#1536)
    + Seam Carving (resizing without distortion) (#1459)
    + Simple image comparison metrics (PSNR, NRMSE) (#1897)
    + Region boundary based region adjacency graphs (RAG) (#1495)
    + Construction of RAG from label images (#1826)
    + "morphology.remove_small_holes" now complements
    "morphology.remove_small_objects" (#1689)
    + Faster cython implementation of "morphology.skeletonize"
    + More appropriate default weights in
    "restoration.denoise_tv_chambolle" and "feature.peak_local_max"
    + Correction of bug in the computation of the Euler characteristic
    in "measure.regionprops".
    + Replace jet by viridis as default colormap
    + Alpha layer support for "color.gray2rgb"
    + The measure of structural similarity ("measure.compare_ssim") is
    now n-dimensional and supports color channels as well.
    + We fixed an issue related to incorrect propagation in plateaus
    in "segmentation.watershed"
  * Documentation:
    + New organization of gallery of examples in sections
    + More frequent (automated) updates of online documentation
  * API Changes
    + "equalize_adapthist" now takes a "kernel_size" keyword argument,
    replacing the "ntiles_*" arguments.
    + The functions "blob_dog", "blob_log" and "blob_doh" now return
    float arrays instead of integer arrays.
    + "transform.integrate" now takes lists of tuples instead of
    integers to define the window over which to integrate.
  * Deprecations
    + "filters.gaussian_filter" has been renamed "filters.gaussian"
    + "filters.gabor_filter" has been renamed "filters.gabor"
    + "restoration.nl_means_denoising" has been renamed
    "restoration.denoise_nl_means"
    + "measure.LineModel" was deprecated in favor of
    "measure.LineModelND"
    + "measure.structural_similarity" has been renamed
    "measure.compare_ssim"
    + "data.lena" has been deprecated, and gallery examples use
    instead the "data.astronaut()" picture.
* Mon Jan 11 2016 toddrme2178@gmail.com
- Fix update-alternatives usage
* Fri Apr  3 2015 arun@gmx.de
- update to version 0.11.3:
  (no changelog entry, taken from git log)
  * Fix handling of non-gif and tiff files
  * Fix setup to allow installing from PyPI
  * Fix support for Sphinx 1.3
  * Add a helper function to check for low contrast
  * Fix RANSAC for invalid model estimation and confidence corner case
* Fri Mar  6 2015 arun@gmx.de
- update to version 0.11.2:
  * Fix DEPENDS markup
  * Fix another formatting error in DEPENDS
* Wed Mar  4 2015 arun@gmx.de
- specfile:
  * update copyright year
  * added networkx, Pillow requirement
- update to version 0.11.0:
  * Highlights:
    + Region Adjacency Graphs
    + Color distance RAGs (#1031)
    + Threshold Cut on RAGs (#1031)
    + Similarity RAGs (#1080)
    + Normalized Cut on RAGs (#1080)
    + RAG drawing (#1087)
    + Hierarchical merging (#1100)
    + Sub-pixel shift registration (#1066)
    + Non-local means denoising (#874)
    + Sliding window histogram (#1127)
    + More illuminants in color conversion (#1130)
    + Handling of CMYK images (#1360)
    + `stop_probability` for RANSAC (#1176)
    + Li thresholding (#1376)
    + Signed edge operators (#1240)
    + Full ndarray support for `peak_local_max` (#1355)
    + Improve conditioning of geometric transformations (#1319)
    + Standardize handling of multi-image files (#1200)
    + Ellipse structuring element (#1298)
    + Multi-line drawing tool (#1065), line handle style (#1179)
    + Point in polygon testing (#1123)
    + Rotation around a specified center (#1168)
    + Add `shape` option to drawing functions (#1222)
    + Faster regionprops (#1351)
    + `skimage.future` package (#1365)
    + More robust I/O module (#1189)
  * API Changes
    + The "skimage.filter" subpackage has been renamed to "skimage.filters".
    + Some edge detectors returned values greater than 1--their
    results are now appropriately scaled with a factor of
    "sqrt(2)".
* Tue Dec 16 2014 arun@gmx.de
- update to version 0.10.1:
  * Fix markup in DEPENDS
  * Update MANIFEST to include all test data
- changes from version 0.10.0:
  - no short list of changes, >980 git commit
* Mon Oct 21 2013 toddrme2178@gmail.com
- Add python3 version
* Mon Oct 21 2013 toddrme2178@gmail.com
- Update to 0.9.3
  * No upstream changelog
- Rename to python-scikit-image to match new naming policy
* Sat Oct 13 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- update version to 0.7.0
* Sun Mar 11 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- initial OBS Build (v0.5.0)
